@@ -1,5 +1,5 @@
 package Hailo::UI::ReadLine;
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 use 5.010;
 use Any::Moose;
 BEGIN {
@@ -15,12 +15,8 @@ use namespace::clean -except => 'meta';
 with qw(Hailo::Role::Arguments
         Hailo::Role::UI);
 
-# Use Gnu readline
 sub BUILD {
-    my ($self) = @_;
-    require Term::ReadLine::Gnu;
-    $ENV{PERL_RL} = 'Gnu';
-    return;
+    $ENV{PERL_RL} = 'Perl o=0' unless $ENV{PERL_RL};
 }
 
 sub run {
